\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ttp}[2024/06/27 v1.0 Trends in Theoretical Physics class]

\LoadClass{article}

\RequirePackage{geometry}
\RequirePackage{setspace}
\RequirePackage{fancyhdr}
\RequirePackage{amsmath}
\RequirePackage{graphicx}
\RequirePackage{ragged2e}
\RequirePackage{multicol}
\RequirePackage{newtxtext,newtxmath}

% Set page dimensions
\geometry{a4paper, columnsep=15mm, left=15mm, right=15mm, top=30mm, bottom=15mm}

\setlength{\columnseprule}{0mm}
\setlength{\footskip}{14.5mm}
\setlength{\headheight}{24.85mm}  
\addtolength{\topmargin}{-24.85mm}

% Define font size commands
\renewcommand\normalsize{%
   \@setfontsize\normalsize\@xiipt{10}}

%%%%%  First page style  %%%%%
\fancypagestyle{firstpage}{
    \fancyhf{}

    %%%%%  HEADER  %%%%%
    % Header line
    \renewcommand{\headrulewidth}{0mm}
    \fancyhead[C]{\makebox[0mm][c]{\raisebox{-4mm}[0mm][0mm]{\color{black}\rule{\headwidth}{0.3mm}}}}
    
    % Logo
    \fancyhead[L]{\raisebox{-1mm}[0mm][0mm]{\includegraphics[width=25mm]{ttp_logo2.jpg}}}

    % Publication date and DOI
    %change the "DOI number goes here" with the actual DOI
    %paste the DOI link in the corresponding field (\href{}) instead of the arbitrary link

    \fancyhead[R]{{\fontsize{8}{10}\selectfont {\fontfamily{lmss}\selectfont Received: dd/mm/yyyy $|$ Published: dd/mm/yyyy \\ \href{https://ttp.andromedapublisher.org/index.php/ttpjournal}{DOI: DOI number goes here}}}}

    %%%%%  FOOTER  %%%%%
    % Page number
    \fancyfoot[C]{\raisebox{2mm}[0mm][0mm]{\fontsize{8}{10}\selectfont {\fontfamily{lmss}\selectfont \thepage}}}
    % Journal Title
    \fancyfoot[L]{\raisebox{2mm}[0mm][0mm]{\fontsize{8}{10}\selectfont {\fontfamily{lmss}\selectfont \href{https://ttp.andromedapublisher.org/index.php/ttpjournal}{Trends in Theoretical Physics}}}}
    % Article details
    \fancyfoot[R]{\raisebox{2mm}[0mm][0mm]{\fontsize{8}{10}\selectfont {\fontfamily{lmss}\selectfont Month 2024 $|$ Volume X $|$ Article XXX}}}
     
}

%%%%%  Other pages style  %%%%%
\pagestyle{fancy}
\fancyhf{}

%%%%%  HEADER  %%%%%
% Header line
\renewcommand{\headrulewidth}{0mm}
\fancyhead[C]{\makebox[0mm][c]{\raisebox{3mm}[0mm][0mm]{\color{black}\rule{\headwidth}{0.3mm}}}}

% Author
\fancyhead[L]{\raisebox{6.5mm}[0mm][0mm]{{\fontsize{8}{10}\selectfont \fontfamily{lmss}\selectfont Author 1 et al.}}}

% DOI
%change the "DOI" word with the actual DOI
%paste the DOI link in the corresponding field (\href{})
\fancyhead[R]{\raisebox{6.5mm}[0mm][0mm]{\fontsize{8}{10}\selectfont {\fontfamily{lmss}\selectfont \href{https://ttp.andromedapublisher.org/index.php/ttpjournal}{DOI: DOI number goes here}}}}

%%%%%  FOOTER  %%%%%
% Page number
\fancyfoot[C]{\raisebox{2mm}[0mm][0mm]{\fontsize{8}{10}\selectfont {\fontfamily{lmss}\selectfont \thepage}}}

% Journal Title
\fancyfoot[L]{\raisebox{2mm}[0mm][0mm]{\fontsize{8}{10}\selectfont {\fontfamily{lmss}\selectfont \href{https://ttp.andromedapublisher.org/index.php/ttpjournal}{Trends in Theoretical Physics}}}}

% Article details
\fancyfoot[R]{\raisebox{2mm}[0mm][0mm]{\fontsize{8}{10}\selectfont {\fontfamily{lmss}\selectfont Month 2024 $|$ Volume X $|$ Article XXX}}}

\pagenumbering{arabic}

\renewcommand{\footrulewidth}{0mm}

%%%%%  ARTICLE TITLE & ABSTRACT FORMAT  %%%%%
\renewcommand{\maketitle}{
    \begin{center}
        \vspace*{15mm}
        \fontfamily{lmss}\fontsize{18}{30}\selectfont \textbf \@title \par
    \end{center}
    
    \vspace{3mm}

    \begin{center}
        \fontfamily{lmss}\fontsize{12}{30}\selectfont \@author \par
    \end{center}
        

    \begin{center}
        \fontsize{8}{10}\selectfont \fontfamily{lmss}\selectfont \textit \@affiliation \par
    \end{center}

    \vspace{3mm}
    
    \begin{center}
        \begin{minipage}{0.8\textwidth} 
            \begin{justify}
                \noindent \fontsize{10}{11}\selectfont \fontfamily{lmss}\selectfont 
                \@abstract
            \end{justify}
        \end{minipage}
    \end{center}
    

    \begin{center}
        \begin{minipage}{0.8\textwidth} 
            \begin{justify}
                \noindent \fontsize{8}{10}\selectfont \textbf{\fontfamily{lmss}\selectfont Keywords: \@keywords}
            \end{justify}
        \end{minipage}
    \end{center}


    \begin{center}
        \begin{minipage}{0.8\textwidth} 
            \begin{justify}
                \noindent \fontsize{8}{10}\selectfont {\textbf{\fontfamily{lmss}\selectfont *Correspondence: \@correspondence}}
            \end{justify}
        \end{minipage}
    \end{center}
    
    \thispagestyle{firstpage}
}

\newcommand{\affiliation}[1]{\gdef\@affiliation{#1}}
\newcommand{\customabstract}[1]{\gdef\@abstract{#1}}
\newcommand{\customkeywords}[1]{\gdef\@keywords{#1}}
\newcommand{\customcorrespondence}[1]{\gdef\@correspondence{#1}}

% Manual section formatting
\renewcommand{\section}{\@startsection{section}{1}{\z@}{-3.5ex \@plus -1ex \@minus -.2ex}{2.3ex \@plus.2ex}{\normalfont\fontfamily{lmss}\fontsize{12}{17}\bfseries}}
\renewcommand{\subsection}{\@startsection{subsection}{2}{\z@}{-3.25ex \@plus -1ex \@minus -.2ex}{1.5ex \@plus .2ex}{\normalfont\fontfamily{lmss}\fontsize{10}{15}\bfseries}}
\renewcommand{\subsubsection}{\@startsection{subsubsection}{3}{\z@}{-3.25ex \@plus -1ex \@minus -.2ex}{1.5ex \@plus .2ex}{\normalfont\fontfamily{lmss}\fontsize{10}{13}\bfseries}}
\renewcommand{\paragraph}{\@startsection{paragraph}{4}{\z@}{3.25ex \@plus1ex \@minus.2ex}{-1em}{\normalfont\fontfamily{lmss}\fontsize{10}{12}\bfseries}}
\renewcommand{\subparagraph}{\@startsection{subparagraph}{5}{\z@}{3.25ex \@plus1ex \@minus.2ex}{-1em}{\normalfont\fontfamily{lmss}\fontsize{10}{11}\bfseries}}


% Load hyperref after setting up page numbering
\RequirePackage{hyperref}
\hypersetup{
    colorlinks=true,
    linkcolor=black,
    urlcolor=black,
    citecolor=black,
}

\endinput
